/********************************************************************************/
/* Test_Display.c - This program is just an example of how to embed image-data	*/
/*	within a C-program, and display the image(s) at run-time, without	*/
/*	needing to reference external image-files at run-time.			*/
/*	It assumes that an image was processed with "image2code", and the data	*/
/*	was placed into file "tmp_data.c", as normal.				*/
/*										*/
/*	To re-use this example, the key routines to copy into your application	*/
/*	are:									*/
/*		decode_image(..)						*/
/*		byte_decode(..)							*/
/*		byte_decode64(..)						*/
/*										*/
/* Compile on Linux or Mac-OSx with:						*/
/*     cc -O -I/usr/X11R6/include -L/usr/X11R6/lib test_display.c  \		*/
/*	-lGLU -lGL -lXmu -lXext -lX11 -lm -o test_display			*/
/*										*/
/* Compile on Microsoft with MinGW:						*/
/*     gcc -O -Lc:\MinGW\lib -Ic:\MinGW\include test_display.c -lglu32 \	*/
/*        -lopengl32 -lwinmm -lgdi32 -lws2_32 -lm -o test_display.exe		*/
/*										*/
/* Run:	  test_display								*/
/*	     (Observe image. Press either button to exit.)			*/
/*										*/
/********************************************************************************/

#include "otk_lib/otk_lib.c"


#include "tmp_data.c"	/* <--- The image-data is included here, produced by "image2code". */

#include "decode_image_data.c"	/* Core Re-Usable Routines */



void ok( void *data )	/* This routine merely provides an action for */
{			/*  the application's buttons. 		      */
 if (data)
  printf("Selected %s\n", (char *)data );
 else
  printf("Selected No\n");
 exit(0);
}



/*----------------------------------- Main -------------------------------------------*/
main( int argc, char **argv )
{
 struct Otk_image *your_image0;

  OtkInitWindow( 600, 360, 1, argv );	/* Create and open a GUI-window called "Application". */
  OtkMakeTextLabel( OtkOuterWindow, "Application", Otk_Black, 8, 2.0, 8, 8 );

  /* This would be the alternative way to display an image, by referencing a file. */
  // OtkMakeImagePanel( OtkOuterWindow, "image.ppm", 14, 26, 70, 34 );  


  /* This is how to display the image from the included data-table. */
  your_image0 = Otk_Make_Image_From_Matrix( "YourImage0", 256, 256, decode_image( imgmtrx_N0, 256, 256, imgmtrxbytes0 ) );
  OtkMakeImagePanel_ImgPtr( OtkOuterWindow, your_image0, 14, 26, 70, 34 );


  /* Make some buttons for the application. */
  OtkMakeButton( OtkOuterWindow, 56, 66, 36, 24, "Yes ", ok, "Yes" );
  OtkMakeButton( OtkOuterWindow, 8, 66, 36, 24, "No ", ok, 0 );
  OtkMainLoop();
}

